@@ -1,5 +1,5 @@
 package MIDI::Drummer::Tiny::Types;
-$MIDI::Drummer::Tiny::Types::VERSION = '0.6007';
+$MIDI::Drummer::Tiny::Types::VERSION = '0.6008';
 our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Type library for MIDI::Drummer::Tiny
@@ -15,8 +15,12 @@ use Type::Library
     ) ],
     -declare => qw(
         Duration
+        MIDI_File
+        Soundfont_File
     );
 use Type::Utils -all;
+use Types::Standard   qw(FileHandle);
+use Types::Path::Tiny qw(File Path);
 
 use MIDI::Util qw(midi_dump);
 
@@ -30,6 +34,22 @@ use MIDI::Util qw(midi_dump);
 my %length = %{ midi_dump('length') };
 declare Duration, as NonEmptyStr, where { exists $length{$_} };
 
+#pod =type MIDI_File
+#pod
+#pod The name of the MIDI file to be written.
+#pod
+#pod =cut
+
+declare MIDI_File, as NonEmptyStr | Path | FileHandle;
+
+#pod =type Soundfont_File
+#pod
+#pod The name of the MIDI soundfont file to use.
+#pod
+#pod =cut
+
+declare Soundfont_File, as NonEmptyStr | File;
+
 1;
 
 __END__
@@ -44,7 +64,7 @@ MIDI::Drummer::Tiny::Types - Type library for MIDI::Drummer::Tiny
 
 =head1 VERSION
 
-version 0.6007
+version 0.6008
 
 =head1 TYPES
 
@@ -53,6 +73,14 @@ version 0.6007
 A L<non-empty string|Types::Common::String/Types> corresponding to
 a L<duration in MIDI::Simple|MIDI::Simple/"Parameters for n/r/noop">.
 
+=head2 MIDI_File
+
+The name of the MIDI file to be written.
+
+=head2 Soundfont_File
+
+The name of the MIDI soundfont file to use.
+
 =head1 AUTHOR
 
 Gene Boggs <gene.boggs@gmail.com>
